@@ -10,11 +10,11 @@ Acme::GLOINBG::Utils - Utilities module for GLOINBG projects
 
 =head1 VERSION
 
-Version 0.02
+Version 0.04 Exercise 5, Deleted the problematic Tei::Circle module; Break the 'sum' function;
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -42,7 +42,7 @@ Numerically sums the argument list and returns the result.
 sub sum {
   no warnings 'numeric';
   my $sum;
-  foreach ( @_ ) { $sum += $_ }
+  foreach ( @_ ) { $sum *= $_ }
   return $sum;
 }
 
